==> GoogleMaps-0.1.5.tar: GoogleMaps/method.upgrade.php <==
<?php
if (!isset($gCms)) exit;

$current_version = $oldversion;
switch($current_version)
{
 case "0.1.2":
   break;
 case "0.1.3":
   $dict = NewDataDictionary($db);

   #change map info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_maps", "description X");
   $dict->ExecuteSQLArray($sqlarray);
   #change marker info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_markers", "info X");
   $dict->ExecuteSQLArray($sqlarray);
   break;
 case "0.1.4":
   $dict = NewDataDictionary($db);

   #change map info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_cache", "lat F");
   $dict->ExecuteSQLArray($sqlarray);
   
   $current_version = "0.1.4";
 case "0.1.4":
 	$config = $gCms->GetConfig();
	// Prepare a directory that will contain the images of the markers and one for the shadows of the markers
	$path = $this->config['uploads_path'].'/'.$this->getName();
	// Make sure the directory can be found. Create it, error handling will cover any problems found
	mkdir($path, 0777);
	$markerspath = $path.DIRECTORY_SEPARATOR.'markers';
	mkdir($markerspath, 0777);
	$markershadowspath = $path.DIRECTORY_SEPARATOR.'markershadows';
	mkdir($markershadowspath, 0777);
	// Copy over the default supplied markers
	$markerdir = dirname(__FILE__).DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'markers';
	if (file_exists( $markerdir ) ) {
		$dir = opendir($markerdir);
		// Filter out the directory controling characters and build selectable options of the others
		while (($file = readdir($dir)) !== false)
		  {
		  	if ($file !='.' && $file!='..') {
	  			copy($markerdir.DIRECTORY_SEPARATOR.$file, $markerspath.DIRECTORY_SEPARATOR.$file);
		  	}
		  }
		closedir($dir);
	}

	$current_version = "0.1.5";
 default:
    break;
}

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

?>

==> GoogleMaps-0.1.6.tar: GoogleMaps/method.upgrade.php <==
<?php
if (!isset($gCms)) exit;

$current_version = $oldversion;
switch($current_version)
{
 case "0.1.2":
   break;
 case "0.1.3":
   $dict = NewDataDictionary($db);

   #change map info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_maps", "description X");
   $dict->ExecuteSQLArray($sqlarray);
   #change marker info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_markers", "info X");
   $dict->ExecuteSQLArray($sqlarray);
   break;
 case "0.1.4":
   $dict = NewDataDictionary($db);

   #change map info to text
   $sqlarray = $dict->AlterColumnSQL(cms_db_prefix()."module_googlemaps_cache", "lat F");
   $dict->ExecuteSQLArray($sqlarray);
   
   $current_version = "0.1.4";
 case "0.1.4":
 	$config = $gCms->GetConfig();
	// Prepare a directory that will contain the images of the markers and one for the shadows of the markers
	$path = $this->config['uploads_path'].'/'.$this->getName();
	// Make sure the directory can be found. Create it, error handling will cover any problems found
	mkdir($path, 0777);
	$markerspath = $path.DIRECTORY_SEPARATOR.'markers';
	mkdir($markerspath, 0777);
	$markershadowspath = $path.DIRECTORY_SEPARATOR.'markershadows';
	mkdir($markershadowspath, 0777);
	// Copy over the default supplied markers
	$markerdir = dirname(__FILE__).DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'markers';
	if (file_exists( $markerdir ) ) {
		$dir = opendir($markerdir);
		// Filter out the directory controling characters and build selectable options of the others
		while (($file = readdir($dir)) !== false)
		  {
		  	if ($file !='.' && $file!='..') {
	  			copy($markerdir.DIRECTORY_SEPARATOR.$file, $markerspath.DIRECTORY_SEPARATOR.$file);
		  	}
		  }
		closedir($dir);
	}

	$current_version = "0.1.5";
 case "0.1.5":
	// No database changes. Only internal changes for the use of parameters   
	$current_version = "0.1.6";
 default:
    break;
}

// put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('upgraded',$this->GetVersion()));

?>
